/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.asset.auto.tagger.google.cloud.natural.language.internal.util;

import com.liferay.portal.kernel.json.JSONUtil;
import com.liferay.portal.kernel.util.ContentTypes;

import java.nio.charset.StandardCharsets;

import java.util.Arrays;

/**
 * @author Alicia García
 * @author Cristina González
 */
public class GCloudNaturalLanguageUtil {

	public static String getDocumentPayload(String content, String type) {
		return JSONUtil.put(
			"document",
			JSONUtil.put(
				"content", content
			).put(
				"type", type
			)
		).toString();
	}

	public static String getType(String mimeType) {
		if (ContentTypes.TEXT_HTML.equals(mimeType)) {
			return "HTML";
		}

		return "PLAIN_TEXT";
	}

	public static String truncateToSize(String content, int size) {
		byte[] bytes = content.getBytes(StandardCharsets.UTF_8);

		if (bytes.length <= size) {
			return content;
		}

		bytes = Arrays.copyOf(bytes, size);

		int i = size - 1;

		while ((bytes[i] & 0x80) != 0) {
			i--;
		}

		if (i < (size - 1)) {
			bytes = Arrays.copyOf(bytes, i + 1);
		}

		return _truncateToWord(new String(bytes, StandardCharsets.UTF_8));
	}

	private static String _truncateToWord(String content) {
		int i = content.length() - 1;

		while ((i > 0) && !Character.isWhitespace(content.charAt(i))) {
			i--;
		}

		return content.substring(0, i);
	}

}